==> morse_2.0.0.tar.gz: morse/R/summary.survData.R <==
#' Summary for survData objects
#' 
#' The generic \code{summary} S3 method for the \code{survData} class provides
#' information about the structure of the dataset and the experimental design.
#' 
#' @param object an object of class \code{survData}
#' @param quiet when \code{FALSE}, prints summary on standard output
#' @param \dots Further arguments to be passed to generic methods.
#' 
#' @return The function returns a list with the following fields:
#' \item{NbrepTimeConc}{nb of replicates for all concentrations and time points}
#' \item{NbsurvTimeConc}{nb of surviving ind. for all concentrations and time points}
#' \item{NbdataConc}{nb of datapoints per concentration}
#' \item{NbdataTime}{nb of datapoints per time}

#' @seealso \code{\link{survData}}
#' 
#' @examples
#' # (1) Load the data
#' data(cadmium1)
#' 
#' # (2) Create a survData object
#' cadmium1 <- survData(cadmium1)
#' 
#' # (3) Summarize the dataset
#' summary(cadmium1)
#' 
#' @keywords summary
#' 
#' @export
#' 
summary.survData <- function(object, quiet = FALSE, ...) {
  # matrix of number of replicate by time / conc
  ans1 <- table(object[, c("conc", "time")])
  
  # matrix of number of survival (sum of all replicate) by time / conc
  ans2 <- tapply(object$Nsurv, list(as.factor(object$conc),
                                    as.factor(object$time)), sum)
  
  # table of datapoints per concentration
  ans3 <- table(object$conc)
  
  # table of datapoints per time
  ans4 <- table(object$time)
  
  if (! quiet) {
    cat("Number of datapoints per concentration: \n")
    print(ans3)
    cat("\nNumber of datapoints per time: \n")
    print(ans4)
    cat("\nNumber of replicate per time and concentration: \n")
    print(ans1)
    cat("\nNumber of survival (sum of replicate) per time and concentration: \n")
    print(ans2)
  }
  
  invisible(list(NbrepTimeConc = ans1,
                 NbsurvTimeConc = ans2,
                 NbdataConc = ans3,
                 NbdataTime = ans4))
}

==> morse_2.1.0.tar.gz: morse/R/summary.survData.R <==
#' Summary for survData objects
#' 
#' The generic \code{summary} S3 method for the \code{survData} class provides
#' information about the structure of the dataset and the experimental design.
#' 
#' @param object an object of class \code{survData}
#' @param quiet when \code{FALSE}, prints summary on standard output
#' @param \dots Further arguments to be passed to generic methods.
#' 
#' @return The function returns a list with the following fields:
#' \item{NbrepTimeConc}{nb of replicates for all concentrations and time points}
#' \item{NbsurvTimeConc}{nb of surviving ind. for all concentrations and time points}

#' @seealso \code{\link{survData}}
#' 
#' @examples
#' # (1) Load the data
#' data(cadmium1)
#' 
#' # (2) Create a survData object
#' cadmium1 <- survData(cadmium1)
#' 
#' # (3) Summarize the dataset
#' summary(cadmium1)
#' 
#' @keywords summary
#' 
#' @export
summary.survData <- function(object, quiet = FALSE, ...) {
  # matrix of number of replicate by time / conc
  ans1 <- table(object[, c("conc", "time")])
  
  # matrix of number of survival (sum of all replicate) by time / conc
  ans2 <- tapply(object$Nsurv, list(as.factor(object$conc),
                                    as.factor(object$time)), sum)
  
  if (! quiet) {
    cat("\nNumber of replicate per time and concentration: \n")
    print(ans1)
    cat("\nNumber of survival (sum of replicate) per time and concentration: \n")
    print(ans2)
  }
  
  invisible(list(NbrepTimeConc = ans1,
                 NbsurvTimeConc = ans2))
}
